@@ -4,7 +4,7 @@ set -ex
 ./build_fe.sh
 ./build_whl.sh
 
-git add data_browser/fe_build data_browser/templates/data_browser/index.html
+git add data_browser/fe_build data_browser/templates/data_browser/index.html README.rst data_browser/__init__.py
 version=$(python -c "import data_browser; print(data_browser.version)")
 set +x
 echo SUCCESS
