@@ -4,10 +4,11 @@ from django.utils.html import format_html
 
 from . import models
 from .common import can_make_public
+from .helpers import AdminMixin
 
 
 @admin.register(models.View)
-class ViewAdmin(admin.ModelAdmin):
+class ViewAdmin(AdminMixin, admin.ModelAdmin):
     fieldsets = [
         (None, {"fields": ["name", "owner", "open_view", "description"]}),
         (
