@@ -1,7 +1,7 @@
 from django.db import models
 
 try:
-    from django.fields import JSONField
+    from django.db.models import JSONField
 except ImportError:  # pragma: django < 3.1
     from django.contrib.postgres.fields import JSONField
 
