@@ -63,7 +63,7 @@ def test_query_query(admin_client, snapshot):
     snapshot.assert_match(query, "query")
 
 
-@pytest.mark.parametrize("format", ["sql", "profile", "pstats"])
+@pytest.mark.parametrize("format", ["sql", "profile", "pstats", "profile_sql"])
 def test_query_misc_formats(admin_client, format):
     # we're not going to check the result as they vary it's sufficient that it doesn't blow up
     res = admin_client.get(
@@ -72,6 +72,16 @@ def test_query_misc_formats(admin_client, format):
     assert res.status_code == 200
 
 
+@pytest.mark.parametrize(
+    "format", ["bad", "profile_bad", "pstats_bad", "profilesql", "pstatsbad"]
+)
+def test_query_bad_formats(admin_client, format):
+    res = admin_client.get(
+        f"/data_browser/query/core.Product/size-0,name+1,size_unit.{format}?size__lt=2&id__gt=0"
+    )
+    assert res.status_code == 404
+
+
 @pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 def test_query_html_no_perms(admin_user, admin_client, snapshot):
     admin_user.is_superuser = False
@@ -134,8 +144,9 @@ def test_query_csv(admin_client):
         "/data_browser/query/core.Product/size-0,name+1,size_unit.csv?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
-    dump(res.content.decode("utf-8"))
-    rows = list(csv.reader(res.content.decode("utf-8").splitlines()))
+    res = res.getvalue().decode("utf-8")
+    dump(res)
+    rows = list(csv.reader(res.splitlines()))
     dump(rows)
     assert rows == [["size", "name", "size_unit"], ["1.0", "a", "g"], ["1.0", "b", "g"]]
 
@@ -146,8 +157,9 @@ def test_query_csv_pivoted(admin_client):
         "/data_browser/query/core.Product/created_time__year+0,&created_time__month+1,id__count,size__max.csv?"
     )
     assert res.status_code == 200
-    dump(res.content.decode("utf-8"))
-    rows = list(csv.reader(res.content.decode("utf-8").splitlines()))
+    res = res.getvalue().decode("utf-8")
+    dump(res)
+    rows = list(csv.reader(res.splitlines()))
     dump(rows)
     assert rows == [
         ["created_time month", "January", "", "Feburary", ""],
@@ -193,8 +205,9 @@ def test_query_csv_pivot_permutations(admin_client, key, snapshot):
         f"/data_browser/query/core.Product/{','.join(fields)}.csv?{filters}"
     )
     assert res.status_code == 200
-    dump(res.content.decode("utf-8"))
-    rows = list(csv.reader(res.content.decode("utf-8").splitlines()))
+    res = res.getvalue().decode("utf-8")
+    dump(res)
+    rows = list(csv.reader(res.splitlines()))
     dump(rows)
     snapshot.assert_match(rows, "key")
 
@@ -243,8 +256,9 @@ def test_view_csv(admin_client, settings):
     view.save()
     res = admin_client.get(f"/data_browser/view/{view.public_slug}.csv")
     assert res.status_code == 200
-    dump(res.content.decode("utf-8"))
-    rows = list(csv.reader(res.content.decode("utf-8").splitlines()))
+    res = res.getvalue().decode("utf-8")
+    dump(res)
+    rows = list(csv.reader(res.splitlines()))
     dump(rows)
     assert rows == [["size", "name", "size_unit"], ["1.0", "a", "g"], ["1.0", "b", "g"]]
 
